//
//  CookieSelectorViewController.swift
//  Desayuno
//
//  Created by Santiago Pavón on 19/04/15.
//  Copyright (c) 2015 UPM. All rights reserved.
//

import UIKit

// Este VC usa una closure (completionHandler) como parametro de entrada para
// configurar lo que hay que ejecutar cuando se selecciona un nuevo tipo de cafe,
// y se presiona OK.
// Se pasa como parametro un String con el nuevo cafe preferido.

class CookieSelectorViewController: UIViewController, UITextFieldDelegate  {

    var currentCookie = ""
    
    // Closure a ejecutar cuando se pulsa OK.
    var completionHandler: ((String) -> ())?
    
    @IBOutlet weak var cookieTextField: UITextField!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        cookieTextField.text = currentCookie
        cookieTextField.delegate = self
    }
   
    // MARK: Acciones de los botones
    
    @IBAction func ok() {
        
        completionHandler?(cookieTextField.text!)
        dismiss(animated: true)
    }
    
    @IBAction func cancel() {
        dismiss(animated: true)
    }


    // MARK: Text Field Delegate
    
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        
        hideKeyboard()
        return true
    }
    
    // MARK: Eventos: al tocar el fondo se oculta el teclado
    
    // He cambiado en el storyboard la clase de la UIView del fondo a UIControl
    
    @IBAction func hideKeyboard() {
        
        // Dejo de ser el primer responder, por lo que se oculta el teclado
        cookieTextField.resignFirstResponder()
    }
}
